Bug 1426446 - Change buttons labels in unverified state. r?markh draft
authorEdouard Oger <eoger@fastmail.com>
Thu, 21 Dec 2017 13:45:28 +0000
changeset 716363 f54f03a03282e5d9531cd51814ea4ea4a0b23eeb
parent 715663 f78a83244fbebe8a469ae3512fce7f638cab7e1f
child 745012 f4b4ce375172ed473bacc9232cebbbda265c5813
push id94406
push userbmo:eoger@fastmail.com
push dateFri, 05 Jan 2018 15:30:29 +0000
reviewersmarkh
bugs1426446
milestone59.0a1
Bug 1426446 - Change buttons labels in unverified state. r?markh MozReview-Commit-ID: 4Dc2JEOJMsa
browser/components/preferences/in-content/sync.xul
browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
browser/locales/en-US/chrome/browser/preferences/sync.dtd
--- a/browser/components/preferences/in-content/sync.xul
+++ b/browser/components/preferences/in-content/sync.xul
@@ -128,18 +128,18 @@
                   <image class="fxaLoginRejectedWarning"/>
                   <description flex="1">
                     &signedInUnverified.beforename.label;
                     <label class="fxaEmailAddress"/>
                     &signedInUnverified.aftername.label;
                   </description>
                 </hbox>
                 <hbox class="fxaAccountBoxButtons">
-                  <button id="verifyFxaAccount" label="&verify.label;" accesskey="&verify.accesskey;"></button>
-                  <button id="unverifiedUnlinkFxaAccount" label="&forget.label;" accesskey="&forget.accesskey;"></button>
+                  <button id="verifyFxaAccount" label="&resendVerification.label;" accesskey="&resendVerification.accesskey;"></button>
+                  <button id="unverifiedUnlinkFxaAccount" label="&cancelSetup.label;" accesskey="&cancelSetup.accesskey;"></button>
                 </hbox>
               </vbox>
             </hbox>
 
             <!-- logged in locally but server rejected credentials -->
             <hbox id="fxaLoginRejected">
               <vbox>
                 <image class="fxaProfileImage"/>
@@ -150,17 +150,17 @@
                   <description flex="1">
                     &signedInLoginFailure.beforename.label;
                     <label class="fxaEmailAddress"/>
                     &signedInLoginFailure.aftername.label;
                   </description>
                 </hbox>
                 <hbox class="fxaAccountBoxButtons">
                   <button id="rejectReSignIn" label="&signIn.label;" accesskey="&signIn.accesskey;"></button>
-                  <button id="rejectUnlinkFxaAccount" label="&forget.label;" accesskey="&forget.accesskey;"></button>
+                  <button id="rejectUnlinkFxaAccount" label="&cancelSetup.label;" accesskey="&cancelSetup.accesskey;"></button>
                 </hbox>
               </vbox>
             </hbox>
           </deck>
         </groupbox>
         <groupbox id="syncOptions">
           <caption><label>&signedIn.settings.label;</label></caption>
           <description>&signedIn.settings.description;</description>
--- a/browser/locales/en-US/chrome/browser/preferences/sync.dtd
+++ b/browser/locales/en-US/chrome/browser/preferences/sync.dtd
@@ -57,28 +57,28 @@ both, to better adapt this sentence to t
 <!-- LOCALIZATION NOTE (signedInLoginFailure.beforename.label,
 signedInLoginFailure.aftername.label): these two string are used respectively
 before and after the account email address. Localizers can use one of them, or
 both, to better adapt this sentence to their language.
 -->
 <!ENTITY signedInLoginFailure.beforename.label "Please sign in to reconnect">
 <!ENTITY signedInLoginFailure.aftername.label "">
 
-<!ENTITY notSignedIn.label           "You are not signed in.">
-<!ENTITY signIn.label                "Sign in">
-<!ENTITY signIn.accesskey            "g">
-<!ENTITY profilePicture.tooltip      "Change profile picture">
-<!ENTITY verifiedManage.label        "Manage account">
-<!ENTITY verifiedManage.accesskey    "o">
-<!ENTITY disconnect3.label           "Disconnect…">
-<!ENTITY disconnect3.accesskey       "D">
-<!ENTITY verify.label                "Verify email">
-<!ENTITY verify.accesskey            "V">
-<!ENTITY forget.label                "Forget this email">
-<!ENTITY forget.accesskey            "F">
+<!ENTITY notSignedIn.label            "You are not signed in.">
+<!ENTITY signIn.label                 "Sign in">
+<!ENTITY signIn.accesskey             "g">
+<!ENTITY profilePicture.tooltip       "Change profile picture">
+<!ENTITY verifiedManage.label         "Manage account">
+<!ENTITY verifiedManage.accesskey     "o">
+<!ENTITY disconnect3.label            "Disconnect…">
+<!ENTITY disconnect3.accesskey        "D">
+<!ENTITY resendVerification.label     "Resend Verification">
+<!ENTITY resendVerification.accesskey "d">
+<!ENTITY cancelSetup.label            "Cancel Setup">
+<!ENTITY cancelSetup.accesskey        "p">
 
 <!ENTITY signedOut.caption            "Take Your Web With You">
 <!ENTITY signedOut.description        "Synchronize your bookmarks, history, tabs, passwords, add-ons, and preferences across all your devices.">
 <!ENTITY signedOut.accountBox.title   "Connect with a &syncBrand.fxAccount.label;">
 <!ENTITY signedOut.accountBox.create2 "Don’t have an account? Get started">
 <!ENTITY signedOut.accountBox.create2.accesskey "C">
 <!ENTITY signedOut.accountBox.signin2 "Sign In…">
 <!ENTITY signedOut.accountBox.signin2.accesskey "I">
--- a/browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
+++ b/browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
@@ -9,18 +9,18 @@
  * Enabling searching functionality. Will display search bar from this testcase forward.
  */
 add_task(async function() {
   await SpecialPowers.pushPrefEnv({"set": [["browser.preferences.search", true]]});
 });
 
 /**
  * Test that we only search the selected child of a XUL deck.
  * When we search "Forget this Email",
  * it should not show the "Forget this Email" button if the Firefox account is not logged in yet.
  */
 add_task(async function() {
   await openPreferencesViaOpenPreferencesAPI("paneGeneral", {leaveOpen: true});
 
   // Ensure the "Sign Up" button in the hidden child of the <xul:deck>
   // is selected and displayed on the screen.
   let weavePrefsDeck = gBrowser.contentDocument.getElementById("weavePrefsDeck");
   is(weavePrefsDeck.selectedIndex, 0, "Should select the #noFxaAccount child node");
@@ -45,23 +45,23 @@ add_task(async function() {
     if (child.id == "header-searchResults" ||
         child.id == "weavePrefsDeck") {
       is_element_visible(child, "Should be in search results");
     } else if (child.id) {
       is_element_hidden(child, "Should not be in search results");
     }
   }
 
   // Ensure the "Forget this email" button exists in the hidden child of the <xul:deck>.
   let unlinkFxaAccount = weavePrefsDeck.childNodes[1].querySelector("#unverifiedUnlinkFxaAccount");
-  is(unlinkFxaAccount.label, "Forget this email", "The Forget this email button should exist");
+  is(unlinkFxaAccount.label, "Cancel Setup", "The Cancel Setup button should exist");
 
   // Performs search.
   searchInput.focus();
-  query = "Forget this Email";
+  query = "Cancel Setup";
   searchCompletedPromise = BrowserTestUtils.waitForEvent(
       gBrowser.contentWindow, "PreferencesSearchCompleted", evt => evt.detail == query);
   EventUtils.sendString(query);
@@ -9,18 +9,18 @@
 /**
  * Test that we only search the selected child of a XUL deck.
- * When we search "Forget this Email",
- * it should not show the "Forget this Email" button if the Firefox account is not logged in yet.
+ * When we search "Cancel Setup",
+ * it should not show the "Cancel Setup" button if the Firefox account is not logged in yet.
  */
 add_task(async function() {
@@ -45,23 +45,23 @@ add_task(async function() {
   }
 
-  // Ensure the "Forget this email" button exists in the hidden child of the <xul:deck>.
+  // Ensure the "Cancel Setup" button exists in the hidden child of the <xul:deck>.
   let unlinkFxaAccount = weavePrefsDeck.childNodes[1].querySelector("#unverifiedUnlinkFxaAccount");
   await searchCompletedPromise;
 
   let noResultsEl = gBrowser.contentDocument.querySelector(".no-results-message");
   is_element_visible(noResultsEl, "Should be reporting no results");
 